@@ -5,7 +5,7 @@ import hashlib
 import io
 import tempfile
 import uuid
-from typing import Optional
+from typing import Literal, Optional
 
 import falcon
 import orjson
@@ -895,16 +895,19 @@ class ImageLogoAnnotateResource:
                     username=auth.get_username() or "unknown",
                     completed_at=completed_at,
                 )
+            else:
+                annotated_logos = []
 
-        logo_ids = [logo.id for logo in annotated_logos]
-        enqueue_job(
-            generate_insights_from_annotated_logos_job,
-            high_queue,
-            {"result_ttl": 0, "timeout": "5m"},
-            logo_ids=logo_ids,
-            server_domain=server_domain,
-            auth=auth,
-        )
+        if annotated_logos:
+            logo_ids = [logo.id for logo in annotated_logos]
+            enqueue_job(
+                generate_insights_from_annotated_logos_job,
+                high_queue,
+                {"result_ttl": 0, "timeout": "5m"},
+                logo_ids=logo_ids,
+                server_domain=server_domain,
+                auth=auth,
+            )
         resp.media = {"annotated": len(annotated_logos)}
 
 
@@ -1093,8 +1096,21 @@ class PopularQuestionsResource:
         get_questions_resource_on_get(req, resp, "popularity")
 
 
+class QuestionsCollectionResource:
+    def on_get(self, req: falcon.Request, resp: falcon.Response):
+        order_by = req.get_param("order_by", default="popularity")
+
+        if order_by not in ("random", "popularity", "confidence"):
+            raise falcon.HTTPBadRequest(
+                description=f"invalid '{order_by}' value for `order_by` parameter"
+            )
+        get_questions_resource_on_get(req, resp, order_by)
+
+
 def get_questions_resource_on_get(
-    req: falcon.Request, resp: falcon.Response, order_by: str
+    req: falcon.Request,
+    resp: falcon.Response,
+    order_by: Literal["random", "popularity", "confidence"],
 ):
     response: JSONType = {}
     page: int = req.get_param_as_int("page", min_value=1, default=1)
@@ -1497,6 +1513,7 @@ api.add_route("/api/v1/ann", ANNResource())
 api.add_route("/api/v1/ann/search/{logo_id:int}", ANNResource())
 api.add_route("/api/v1/ann/search", ANNResource())
 api.add_route("/api/v1/questions/{barcode}", ProductQuestionsResource())
+api.add_route("/api/v1/questions", QuestionsCollectionResource())
 api.add_route("/api/v1/questions/random", RandomQuestionsResource())
 api.add_route("/api/v1/questions/popular", PopularQuestionsResource())
 api.add_route("/api/v1/questions/unanswered", UnansweredQuestionCollection())
