@@ -73,7 +73,7 @@ def regenerate_ocr_insights(
 
     with db:
         import_result = importer.import_insights(
-            predictions, settings.OFF_SERVER_DOMAIN
+            predictions, settings.BaseURLProvider.server_domain()
         )
         logger.info(import_result)
 
@@ -208,7 +208,7 @@ def import_insights(
             # Create a new transaction for every batch
             with db.atomic():
                 import_results = importer.import_insights(
-                    prediction_batch, settings.OFF_SERVER_DOMAIN
+                    prediction_batch, settings.BaseURLProvider.server_domain()
                 )
                 logger.info(import_results)
 
@@ -245,7 +245,9 @@ def refresh_insights(
     if barcode is not None:
         logger.info(f"Refreshing product {barcode}")
         with db:
-            imported = refresh_insights_(barcode, settings.OFF_SERVER_DOMAIN)
+            imported = refresh_insights_(
+                barcode, settings.BaseURLProvider.server_domain()
+            )
         logger.info(f"Refreshed insights: {imported}")
     else:
         logger.info("Launching insight refresh on full database")
@@ -272,7 +274,7 @@ def refresh_insights(
                 low_queue,
                 job_kwargs={"result_ttl": 0, "timeout": "5m"},
                 barcodes=barcode_batch,
-                server_domain=settings.OFF_SERVER_DOMAIN,
+                server_domain=settings.BaseURLProvider.server_domain(),
             )
 
 
@@ -323,7 +325,7 @@ def import_images_in_db(
                 low_queue,
                 job_kwargs={"result_ttl": 0},
                 batch=batch,
-                server_domain=settings.OFF_SERVER_DOMAIN,
+                server_domain=settings.BaseURLProvider.server_domain(),
             )
 
 
@@ -415,7 +417,7 @@ def run_object_detection_model(
                 job_kwargs={"result_ttl": 0},
                 barcode=barcode,
                 image_url=image_url,
-                server_domain=settings.OFF_SERVER_DOMAIN,
+                server_domain=settings.BaseURLProvider.server_domain(),
             )
 
 
@@ -564,21 +566,52 @@ def import_embedding(
 
 @app.command()
 def import_logos(
-    data_path: pathlib.Path,
-    model_name: str = "universal-logo-detector",
-    model_version: str = "tf-universal-logo-detector-1.0",
+    data_path: pathlib.Path = typer.Argument(
+        ...,
+        help="Path to the JSONL file containing data to import",
+        exists=True,
+        file_okay=True,
+        dir_okay=False,
+    ),
+    batch_size: int = typer.Option(
+        1024, help="Number of predictions to insert in DB in a single SQL transaction"
+    ),
 ) -> None:
-    from robotoff.cli.logos import insert_batch
+    """Import object detection predictions for universal-logo-detector model.
+
+    This command creates ImagePrediction and associated LogoAnnotation, but do
+    not generate logo embedding or index the embeddings in the ANN index.
+
+    Each JSON item should have the following field:
+
+    - barcode: the barcode of the product
+    - image_id: the image ID ("1", "2",...), must be a digit
+    - result: a dict, containing:
+        - score: the confidence score (float)
+        - bounding_box: a list with 4 elements, corresponding to the
+          normalized detected bounding box
+        - label: either `label` or `brand`
+
+    """
+    from robotoff.cli import logos
     from robotoff.models import db
+    from robotoff.prediction.object_detection import OBJECT_DETECTION_MODEL_VERSION
     from robotoff.utils import get_logger
 
     logger = get_logger()
-    logger.info("Starting image prediction import...")
+    logger.info("Starting logo import...")
 
-    with db:
-        inserted = insert_batch(data_path, model_name, model_version)
+    with db.connection_context():
+        imported = logos.import_logos(
+            data_path,
+            ObjectDetectionModel.universal_logo_detector.value,
+            OBJECT_DETECTION_MODEL_VERSION[
+                ObjectDetectionModel.universal_logo_detector
+            ],
+            batch_size,
+        )
 
-    logger.info("{} image predictions inserted".format(inserted))
+    logger.info("%s image predictions created", imported)
 
 
 @app.command()
