@@ -28,6 +28,7 @@ from robotoff.types import (
     PredictionType,
 )
 from robotoff.utils import get_logger
+from robotoff.utils.text import get_tag
 
 logger = get_logger(__name__)
 
@@ -351,6 +352,18 @@ def import_logo_insights(
     return import_result
 
 
+def generate_insights_from_annotated_logos_job(
+    logo_ids: list[int], server_domain: str, auth: OFFAuthentication
+):
+    """Wrap generate_insights_from_annotated_logos function into a python-rq
+    compatible job."""
+    with db:
+        logos = list(LogoAnnotation.select().where(LogoAnnotation.id.in_(logo_ids)))
+
+        if logos:
+            generate_insights_from_annotated_logos(logos, server_domain, auth)
+
+
 def generate_insights_from_annotated_logos(
     logos: list[LogoAnnotation], server_domain: str, auth: OFFAuthentication
 ) -> int:
@@ -458,7 +471,8 @@ def generate_prediction(
     value = None
 
     if prediction_type == PredictionType.brand:
-        value_tag = value = logo_value
+        value = logo_value
+        value_tag = get_tag(value)
 
     elif prediction_type == PredictionType.label:
         value_tag = logo_value
@@ -515,7 +529,7 @@ def refresh_nearest_neighbors(day_offset: int = 7, batch_size: int = 500):
                 import_logo_insights(
                     logos,
                     thresholds=thresholds,
-                    server_domain=settings.OFF_SERVER_DOMAIN,
+                    server_domain=settings.BaseURLProvider.server_domain(),
                     notify=False,
                 )
 
