@@ -1,3 +1,3 @@
 # flake8: noqa
-from .core import extract_predictions, ocr_iter
+from .core import extract_predictions
 from .dataclass import OCRResult
