@@ -9,8 +9,8 @@ from robotoff.prediction.category.neural.category_classifier import CategoryClas
 from robotoff.products import get_product
 from robotoff.redis import Lock, LockedResourceException
 from robotoff.taxonomy import TaxonomyType, get_taxonomy
+from robotoff.types import JSONType
 from robotoff.utils import get_logger
-from robotoff.utils.types import JSONType
 
 logger = get_logger(__name__)
 
@@ -39,7 +39,7 @@ def update_insights_job(barcode: str, server_domain: str):
             product_dict = get_product(barcode)
 
             if product_dict is None:
-                logger.warning("Updated product does not exist: %s", barcode)
+                logger.info("Updated product does not exist: %s", barcode)
                 return
 
             updated_product_predict_insights(barcode, product_dict, server_domain)
